==> legato-dist-core-1.3.0-dist.tar.gz: Legato-Core-1.3.0/lib/Legato/OpenLayers/Bounds.js <==
/*
 * Legato is a configurable, lightweight web mapping client that can be
 * easily embedded into web pages and portals, CMS and individual web
 * applications. Legato is implemented in JavaScript and based on the
 * popular open source library OpenLayers.
 *
 * Copyright (C) 2010  disy Informationssysteme GmbH, http://www.disy.net
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */

/**
 * Component: ol:Bounds
 * 
 * See also:
 * - <ol> namespace.
 * - {<OpenLayers.Bounds>}
 */

OpenLayers.Bounds.Bean = Legato.Beans.Object.Extend('OpenLayers.Bounds',
//
Legato.OpenLayers.QName('Bounds'),
//
{
	_constructor : OpenLayers.Bounds,
	constructorArguments : {
		/**
		 * Element: left
		 * {Number}
		 */
		left : Legato.Lang.Number,
		/**
		 * Element: bottom
		 * {Number}
		 */
		bottom : Legato.Lang.Number,
		/**
		 * Element: right
		 * {Number}
		 */
		right : Legato.Lang.Number,
		/**
		 * Element: top
		 * {Number}
		 */
		top : Legato.Lang.Number

	},
	constructorOrder : [ 'left', 'bottom', 'right', 'top' ]
});

==> legato-dist-core-2.0.0-dist.tar.gz: Legato-Core-2.0.0/lib/Legato/OpenLayers/Bounds.js <==
/*
 * Legato is a configurable, lightweight web mapping client that can be
 * easily embedded into web pages and portals, CMS and individual web
 * applications. Legato is implemented in JavaScript and based on the
 * popular open source library OpenLayers.
 *
 * Copyright (C) 2010  disy Informationssysteme GmbH, http://www.disy.net
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */

/**
 * Component: ol:Bounds
 * 
 * See also:
 * - <ol> namespace.
 * - {<OpenLayers.Bounds>}
 */

OpenLayers.Bounds.Bean = Legato.Beans.Object.Extend('OpenLayers.Bounds',
//
Legato.OpenLayers.QName('Bounds'),
//
{
	// Using factoryFunction instead of _constructor approach because
	// OpenLayers now checks for instance equality with "instanceof"
	// which fails if the object isn't created with the new() operator.
	factoryFunction : function(left, bottom, right, top) {
		return new OpenLayers.Bounds(left, bottom, right, top);
	},
	constructorArguments : {
		/**
		 * Element: left
		 * {Number}
		 */
		left : Legato.Lang.Number,
		/**
		 * Element: bottom
		 * {Number}
		 */
		bottom : Legato.Lang.Number,
		/**
		 * Element: right
		 * {Number}
		 */
		right : Legato.Lang.Number,
		/**
		 * Element: top
		 * {Number}
		 */
		top : Legato.Lang.Number

	},
	constructorOrder : [ 'left', 'bottom', 'right', 'top' ]
});
